@@ -22,10 +22,8 @@ use tokio::{
     sync::{mpsc::Receiver, RwLock},
     time::Duration,
 };
-use tracing::{debug, info, trace};
+use tracing::info;
 
-// Number of attempts to make when trying to bootstrap to the network
-const NUM_OF_BOOTSTRAPPING_ATTEMPTS: u8 = 1;
 const BLOB_CACHE_CAP: usize = 150;
 
 /// Client object
@@ -73,15 +71,17 @@ impl Client {
         // Incoming error notifiers
         let (err_sender, err_receiver) = tokio::sync::mpsc::channel::<CmdError>(10);
 
-        // Create the session with the network
-        let mut session = Session::new(config.qp2p, err_sender)?;
-
         let client_pk = keypair.public_key();
 
-        // Bootstrap to the network, connecting to the section responsible
-        // for our client public key
-        debug!("Bootstrapping to the network...");
-        attempt_bootstrap(&mut session, client_pk).await?;
+        // Create the session with the network
+        let session = Session::new(
+            client_pk,
+            config.local_addr,
+            &config.bootstrap_nodes,
+            config.qp2p,
+            err_sender,
+        )
+        .await?;
 
         let client = Self {
             keypair,
@@ -128,29 +128,6 @@ impl Client {
     }
 }
 
-/// Utility function that bootstraps a client to the network. If there is a failure then it retries.
-/// After a maximum of three attempts if the boostrap process still fails, then an error is returned.
-async fn attempt_bootstrap(session: &mut Session, client_pk: PublicKey) -> Result<(), Error> {
-    let mut attempts: u8 = 0;
-    loop {
-        match session.bootstrap(client_pk).await {
-            Ok(()) => return Ok(()),
-            Err(err) => {
-                attempts += 1;
-                if attempts < NUM_OF_BOOTSTRAPPING_ATTEMPTS {
-                    trace!(
-                        "Error connecting to network! {:?}\nRetrying... ({})",
-                        err,
-                        attempts
-                    );
-                } else {
-                    return Err(err);
-                }
-            }
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
