@@ -20,6 +20,7 @@ pub use self::{
     cmd::DataCmd,
     data_exchange::{
         ChunkDataExchange, ChunkMetadata, DataExchange, HolderMetadata, RegisterDataExchange,
+        StorageLevel,
     },
     errors::{Error, Result},
     query::DataQuery,
@@ -29,10 +30,16 @@ pub use self::{
 use crate::messaging::{data::Error as ErrorMessage, MessageId};
 use crate::types::{
     register::{Entry, EntryHash, Permissions, Policy, Register},
-    Chunk, PublicKey,
+    Chunk, DataAddress, PublicKey,
 };
+use bytes::Bytes;
 use serde::{Deserialize, Serialize};
 use std::{collections::BTreeSet, convert::TryFrom};
+use xor_name::XorName;
+
+/// Derivable Id of an operation. Query/Response should return the same id for simple tracking purposes.
+/// TODO: make uniquer per requester for some operations
+pub type OperationId = String;
 
 /// A message indicating that an error occurred as a node was handling a client's message.
 #[allow(clippy::large_enum_variant)]
@@ -45,7 +52,7 @@ pub struct ServiceError {
     /// Message that triggered this error.
     ///
     /// This could be used to retry the message if the error could be handled.
-    pub source_message: Option<Box<ServiceMsg>>,
+    pub source_message: Option<Bytes>,
 }
 
 /// Network service messages that clients or nodes send in order to use the services,
@@ -87,6 +94,17 @@ pub enum ServiceMsg {
     ServiceError(ServiceError),
 }
 
+impl ServiceMsg {
+    /// Returns the destination address for Commands and Queries only.
+    pub fn dst_address(&self) -> Option<XorName> {
+        match self {
+            Self::Cmd(cmd) => Some(cmd.dst_name()),
+            Self::Query(query) => Some(query.dst_name()),
+            _ => None,
+        }
+    }
+}
+
 /// An error response to a [`Cmd`].
 ///
 /// [`Cmd`]: ServiceMsg::Cmd
@@ -98,6 +116,7 @@ pub enum CmdError {
 }
 
 /// The response to a query, containing the query result.
+/// Response operation id should match query operation_id
 #[allow(clippy::large_enum_variant, clippy::type_complexity)]
 #[derive(Eq, PartialEq, Clone, Serialize, Deserialize, Debug)]
 pub enum QueryResponse {
@@ -110,15 +129,15 @@ pub enum QueryResponse {
     // ===== Register Data =====
     //
     /// Response to [`RegisterRead::Get`].
-    GetRegister(Result<Register>),
+    GetRegister((Result<Register>, OperationId)),
     /// Response to [`RegisterRead::GetOwner`].
-    GetRegisterOwner(Result<PublicKey>),
+    GetRegisterOwner((Result<PublicKey>, OperationId)),
     /// Response to [`RegisterRead::Read`].
-    ReadRegister(Result<BTreeSet<(EntryHash, Entry)>>),
+    ReadRegister((Result<BTreeSet<(EntryHash, Entry)>>, OperationId)),
     /// Response to [`RegisterRead::GetPolicy`].
-    GetRegisterPolicy(Result<Policy>),
+    GetRegisterPolicy((Result<Policy>, OperationId)),
     /// Response to [`RegisterRead::GetUserPermissions`].
-    GetRegisterUserPermissions(Result<Permissions>),
+    GetRegisterUserPermissions((Result<Permissions>, OperationId)),
 }
 
 impl QueryResponse {
@@ -127,11 +146,11 @@ impl QueryResponse {
         use QueryResponse::*;
         match self {
             GetChunk(result) => result.is_ok(),
-            GetRegister(result) => result.is_ok(),
-            GetRegisterOwner(result) => result.is_ok(),
-            ReadRegister(result) => result.is_ok(),
-            GetRegisterPolicy(result) => result.is_ok(),
-            GetRegisterUserPermissions(result) => result.is_ok(),
+            GetRegister((result, _op_id)) => result.is_ok(),
+            GetRegisterOwner((result, _op_id)) => result.is_ok(),
+            ReadRegister((result, _op_id)) => result.is_ok(),
+            GetRegisterPolicy((result, _op_id)) => result.is_ok(),
+            GetRegisterUserPermissions((result, _op_id)) => result.is_ok(),
         }
     }
 
@@ -144,28 +163,60 @@ impl QueryResponse {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
-            GetRegister(result) => match result {
+            GetRegister((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
-            GetRegisterOwner(result) => match result {
+            GetRegisterOwner((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
-            ReadRegister(result) => match result {
+            ReadRegister((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
-            GetRegisterPolicy(result) => match result {
+            GetRegisterPolicy((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
-            GetRegisterUserPermissions(result) => match result {
+            GetRegisterUserPermissions((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
         }
     }
+
+    /// Retrieves the operation identifier for this response, use in tracking node liveness
+    /// and responses at clients.
+    /// Right now returning result to fail for anything non-chunk, as that's all we're tracking from other nodes here just now.
+    pub fn operation_id(&self) -> Result<OperationId> {
+        use QueryResponse::*;
+
+        // TODO: Operation Id should eventually encompass _who_ the op is for.
+        match self {
+            GetChunk(result) => match result {
+                Ok(chunk) => chunk
+                    .address()
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId),
+                Err(error) => match error {
+                    ErrorMessage::DataNotFound(address) => match address {
+                        DataAddress::Chunk(address) => address
+                            .encode_to_zbase32()
+                            .map_err(|_| Error::NoOperationId),
+                        _ => Err(Error::NoOperationId),
+                    },
+                    _ => Err(Error::InvalidQueryResponseErrorForOperationId),
+                },
+            },
+
+            GetRegister((_, operation_id))
+            | GetRegisterOwner((_, operation_id))
+            | ReadRegister((_, operation_id))
+            | GetRegisterPolicy((_, operation_id))
+            | GetRegisterUserPermissions((_, operation_id)) => Ok(operation_id.clone()),
+        }
+    }
 }
 
 /// Error type for an attempted conversion from a [`QueryResponse`] variant to an expected wrapped
@@ -186,8 +237,8 @@ macro_rules! try_from {
             fn try_from(response: QueryResponse) -> std::result::Result<Self, Self::Error> {
                 match response {
                     $(
-                        QueryResponse::$variant(Ok(data)) => Ok(data),
-                        QueryResponse::$variant(Err(error)) => Err(TryFromError::Response(error)),
+                        QueryResponse::$variant((Ok(data), _op_id)) => Ok(data),
+                        QueryResponse::$variant((Err(error), _op_id)) => Err(TryFromError::Response(error)),
                     )*
                     _ => Err(TryFromError::WrongType),
                 }
@@ -196,7 +247,19 @@ macro_rules! try_from {
     };
 }
 
-try_from!(Chunk, GetChunk);
+// try_from!(Chunk, GetChunk);
+
+impl TryFrom<QueryResponse> for Chunk {
+    type Error = TryFromError;
+    fn try_from(response: QueryResponse) -> std::result::Result<Self, Self::Error> {
+        match response {
+            QueryResponse::GetChunk(Ok(data)) => Ok(data),
+            QueryResponse::GetChunk(Err(error)) => Err(TryFromError::Response(error)),
+            _ => Err(TryFromError::WrongType),
+        }
+    }
+}
+
 try_from!(Register, GetRegister);
 try_from!(PublicKey, GetRegisterOwner);
 try_from!(BTreeSet<(EntryHash, Entry)>, ReadRegister);
@@ -206,10 +269,9 @@ try_from!(Permissions, GetRegisterUserPermissions);
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::types::{ChunkAddress, DataAddress, Keypair, PrivateChunk};
+    use crate::types::{Keypair, PrivateChunk};
     use eyre::{eyre, Result};
     use std::convert::{TryFrom, TryInto};
-    use xor_name::XorName;
 
     fn gen_keypairs() -> Vec<Keypair> {
         let mut rng = rand::thread_rng();
@@ -231,48 +293,17 @@ mod tests {
     #[test]
     fn debug_format_functional() -> Result<()> {
         if let Some(key) = gen_keys().first() {
-            let errored_response = QueryResponse::GetRegister(Err(Error::AccessDenied(*key)));
-            assert!(format!("{:?}", errored_response).contains("GetRegister(Err(AccessDenied("));
+            let errored_response = QueryResponse::GetRegister((
+                Err(Error::AccessDenied(*key)),
+                "some_op_id".to_string(),
+            ));
+            assert!(format!("{:?}", errored_response).contains("GetRegister((Err(AccessDenied("));
             Ok(())
         } else {
             Err(eyre!("Could not generate public key"))
         }
     }
 
-    #[test]
-    fn generate_service_error() {
-        let msg = ServiceMsg::Query(DataQuery::Chunk(ChunkRead::Get(ChunkAddress::Private(
-            XorName::random(),
-        ))));
-        let random_addr = DataAddress::Chunk(ChunkAddress::Public(XorName::random()));
-        let lazy_error = ServiceError {
-            reason: Some(Error::DataNotFound(random_addr.clone())),
-            source_message: Some(Box::new(msg)),
-        };
-
-        assert!(format!("{:?}", lazy_error).contains("Chunk(Get(Private"));
-        assert!(format!("{:?}", lazy_error).contains("ServiceError"));
-        assert!(format!("{:?}", lazy_error).contains(&format!("DataNotFound({:?})", random_addr)));
-    }
-
-    #[test]
-    fn debug_format_service_error() {
-        let chunk_addr = ChunkAddress::Public(XorName::random());
-        let random_addr = DataAddress::Chunk(chunk_addr);
-        let errored_response = ServiceError {
-            reason: Some(Error::DataNotFound(random_addr.clone())),
-            source_message: Some(Box::new(ServiceMsg::Query(DataQuery::Chunk(
-                ChunkRead::Get(chunk_addr),
-            )))),
-        };
-
-        assert!(format!("{:?}", errored_response).contains("Chunk(Get(Public"));
-        assert!(format!("{:?}", errored_response).contains("ServiceError"));
-        assert!(
-            format!("{:?}", errored_response).contains(&format!("DataNotFound({:?})", random_addr))
-        );
-    }
-
     #[test]
     fn try_from() -> Result<()> {
         use QueryResponse::*;
